// https://nuxt.com/docs/api/configuration/nuxt-config
export default defineNuxtConfig({
  devtools: { enabled: true },
  modules: ['@nuxtjs/tailwindcss', '@nuxt/image', '@hypernym/nuxt-anime'],
  vite: {
    css: {
      preprocessorOptions: {
        scss: {
          additionalData: '@use "@/assets/css/_var.scss" as *;',
        }
      }
    }
  },
  plugins: [
    "@/plugins/vue-scrollto.js",
    "@/plugins/echarts.js",
    { src: '~/plugins/aos', mode: 'client' }
  ],
  app: {
    baseURL: '/hkpolyu/',
    head: {
      title: 'PolYneer - iGEM 2023',
      meta: [
        { charset: 'utf-8' },
        { name: 'viewport', content: 'width=device-width, initial-scale=1, user-scalable=0, maximum-scale=1, minimum-scale=1' },
        { hid: 'description', name: 'description', content: 'PolYneer - iGEM 2023' }
      ],
      link: [
        { rel: 'icon', type: 'image/x-icon', href: 'https://static.igem.wiki/teams/4774/wiki/static/favicon.ico' }
      ]
    }
  },
  image: {
    domains: ['static.igem.wiki']
  },
  build: {
    transpile: ['echarts'],
    postcss: {
      postcssOptions: {
        preset: {
          autoprefixer: {
            grid: true,
            overrideBrowserslist: ['last 3 versions', '> 1%', 'ie 8', 'ie 7'],
          }
        }
      }
    }
  },
  alias: {
    // tslib: 'node_modules/tslib/tslib.es6.mjs',
    'resize-detector': 'node_modules/resize-detector/esm/index.js'
  },
  css: [
    'swiper/css',
    'swiper/css/navigation',
    'swiper/css/pagination',
    'swiper/css/effect-coverflow'
  ]
})